@@ -49,7 +49,7 @@
 
     MIT License:
 
-    Copyright (c) 2020 David Cortes
+    Copyright (c) 2021 David Cortes
 
     All rights reserved.
 
@@ -148,7 +148,7 @@ SEXP call_fit_collective_explicit_lbfgs
     SEXP n_corr_pairs, SEXP maxiter, SEXP print_every,
     SEXP nupd, SEXP nfev,
     SEXP prefer_onepass,
-    SEXP nthreads, SEXP verbose, SEXP handle_interrupt,
+    SEXP nthreads, SEXP verbose,
     SEXP precompute,
     SEXP include_all_X,
     SEXP B_plus_bias,
@@ -194,7 +194,7 @@ SEXP call_fit_collective_explicit_lbfgs
         Rf_asReal(w_main), Rf_asReal(w_user), Rf_asReal(w_item),
         Rf_asInteger(n_corr_pairs), (size_t) Rf_asInteger(maxiter),
         Rf_asInteger(nthreads), (bool) Rf_asLogical(prefer_onepass),
-        (bool) Rf_asLogical(verbose), Rf_asInteger(print_every), (bool) Rf_asLogical(handle_interrupt),
+        (bool) Rf_asLogical(verbose), Rf_asInteger(print_every),
         INTEGER(nupd), INTEGER(nfev),
         (bool) Rf_asLogical(precompute),
         (bool) Rf_asLogical(include_all_X),
@@ -236,7 +236,7 @@ SEXP call_fit_collective_explicit_als
     SEXP NA_as_zero_X, SEXP NA_as_zero_U, SEXP NA_as_zero_I,
     SEXP k_main_k_user_k_item,
     SEXP w_main_w_user_w_item_w_implicit,
-    SEXP niter, SEXP nthreads, SEXP verbose, SEXP handle_interrupt,
+    SEXP niter, SEXP nthreads, SEXP verbose,
     SEXP use_cg, SEXP max_cg_steps, SEXP finalize_chol,
     SEXP nonneg, SEXP max_cd_steps, SEXP nonneg_CD,
     SEXP precompute,
@@ -306,7 +306,7 @@ SEXP call_fit_collective_explicit_als
         (bool) Rf_asLogical(NA_as_zero_X), (bool) Rf_asLogical(NA_as_zero_U), (bool) Rf_asLogical(NA_as_zero_I),
         k_main, k_user, k_item,
         w_main, w_user, w_item, w_implicit,
-        Rf_asInteger(niter), Rf_asInteger(nthreads), (bool) Rf_asLogical(verbose), (bool) Rf_asLogical(handle_interrupt),
+        Rf_asInteger(niter), Rf_asInteger(nthreads), (bool) Rf_asLogical(verbose),
         (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
         (bool) Rf_asLogical(nonneg), (size_t) Rf_asInteger(max_cd_steps),
         nonneg_C, nonneg_D,
@@ -345,7 +345,7 @@ SEXP call_fit_collective_implicit_als
     SEXP NA_as_zero_U, SEXP NA_as_zero_I,
     SEXP k_main, SEXP k_user, SEXP k_item,
     SEXP w_main, SEXP w_user, SEXP w_item,
-    SEXP niter, SEXP nthreads, SEXP verbose, SEXP handle_interrupt,
+    SEXP niter, SEXP nthreads, SEXP verbose,
     SEXP use_cg, SEXP max_cg_steps, SEXP finalize_chol,
     SEXP nonneg, SEXP max_cd_steps, SEXP nonneg_C, SEXP nonneg_D,
     SEXP alpha, SEXP adjust_weight, SEXP apply_log_transf,
@@ -387,7 +387,7 @@ SEXP call_fit_collective_implicit_als
         REAL(w_main_multiplier),
         Rf_asReal(alpha), (bool) Rf_asLogical(adjust_weight),
         (bool) Rf_asLogical(apply_log_transf),
-        Rf_asInteger(niter), Rf_asInteger(nthreads), (bool) Rf_asLogical(verbose), (bool) Rf_asLogical(handle_interrupt),
+        Rf_asInteger(niter), Rf_asInteger(nthreads), (bool) Rf_asLogical(verbose),
         (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
         (bool) Rf_asLogical(nonneg), (size_t) Rf_asInteger(max_cd_steps),
         (bool) Rf_asLogical(nonneg_C), (bool) Rf_asLogical(nonneg_D),
@@ -490,7 +490,7 @@ SEXP call_fit_content_based_lbfgs
     SEXP I_row, SEXP I_col, SEXP I_sp,
     SEXP n_corr_pairs, SEXP maxiter,
     SEXP nthreads, SEXP prefer_onepass,
-    SEXP verbose, SEXP print_every, SEXP handle_interrupt,
+    SEXP verbose, SEXP print_every,
     SEXP niter, SEXP nfev,
     SEXP Am, SEXP Bm
 )
@@ -526,7 +526,7 @@ SEXP call_fit_content_based_lbfgs
         get_ptr_int(I_row), get_ptr_int(I_col), get_ptr(I_sp), (size_t)Rf_xlength(I_sp),
         Rf_asInteger(n_corr_pairs), (size_t) Rf_asInteger(maxiter),
         Rf_asInteger(nthreads), (bool) Rf_asLogical(prefer_onepass),
-        (bool) Rf_asLogical(verbose), Rf_asInteger(print_every), (bool) Rf_asLogical(handle_interrupt),
+        (bool) Rf_asLogical(verbose), Rf_asInteger(print_every),
         INTEGER(niter), INTEGER(nfev),
         REAL(Am), REAL(Bm)
     );
@@ -561,7 +561,7 @@ SEXP call_fit_offsets_explicit_lbfgs
     SEXP w_user, SEXP w_item,
     SEXP n_corr_pairs, SEXP maxiter,
     SEXP nthreads, SEXP prefer_onepass,
-    SEXP verbose, SEXP print_every, SEXP handle_interrupt,
+    SEXP verbose, SEXP print_every,
     SEXP niter, SEXP nfev,
     SEXP precompute,
     SEXP Am, SEXP Bm,
@@ -602,7 +602,7 @@ SEXP call_fit_offsets_explicit_lbfgs
         Rf_asReal(w_user), Rf_asReal(w_item),
         Rf_asInteger(n_corr_pairs), (size_t) Rf_asInteger(maxiter),
         Rf_asInteger(nthreads), (bool) Rf_asLogical(prefer_onepass),
-        (bool) Rf_asLogical(verbose), Rf_asInteger(print_every), (bool) Rf_asLogical(handle_interrupt),
+        (bool) Rf_asLogical(verbose), Rf_asInteger(print_every),
         INTEGER(niter), INTEGER(nfev),
         (bool) Rf_asLogical(precompute),
         get_ptr(Am), get_ptr(Bm),
@@ -638,7 +638,7 @@ SEXP call_fit_offsets_explicit_als
     SEXP niter,
     SEXP nthreads, SEXP use_cg,
     SEXP max_cg_steps, SEXP finalize_chol,
-    SEXP verbose, SEXP handle_interrupt,
+    SEXP verbose,
     SEXP precompute,
     SEXP Am, SEXP Bm,
     SEXP Bm_plus_bias,
@@ -672,7 +672,7 @@ SEXP call_fit_offsets_explicit_als
         Rf_asInteger(niter),
         Rf_asInteger(nthreads), (bool) Rf_asLogical(use_cg),
         Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
-        (bool) Rf_asLogical(verbose), (bool) Rf_asLogical(handle_interrupt),
+        (bool) Rf_asLogical(verbose),
         (bool) Rf_asLogical(precompute),
         get_ptr(Am), get_ptr(Bm),
         get_ptr(Bm_plus_bias),
@@ -701,7 +701,7 @@ SEXP call_fit_offsets_implicit_als
     SEXP niter,
     SEXP nthreads, SEXP use_cg,
     SEXP max_cg_steps, SEXP finalize_chol,
-    SEXP verbose, SEXP handle_interrupt,
+    SEXP verbose,
     SEXP precompute,
     SEXP Am, SEXP Bm,
     SEXP BtB
@@ -722,7 +722,7 @@ SEXP call_fit_offsets_implicit_als
         Rf_asInteger(niter),
         Rf_asInteger(nthreads), (bool) Rf_asLogical(use_cg),
         Rf_asInteger(max_cg_steps), (bool) Rf_asLogical(finalize_chol),
-        (bool) Rf_asLogical(verbose), (bool) Rf_asLogical(handle_interrupt),
+        (bool) Rf_asLogical(verbose),
         (bool) Rf_asLogical(precompute),
         get_ptr(Am), get_ptr(Bm),
         get_ptr(BtB)
@@ -2371,14 +2371,14 @@ static const R_CallMethodDef callMethods [] = {
     {"deep_copy", (DL_FUNC) &deep_copy, 1},
     {"as_size_t", (DL_FUNC) &as_size_t, 1},
     /* ---------------------------------------------------- */
-    {"call_fit_collective_explicit_lbfgs", (DL_FUNC) &call_fit_collective_explicit_lbfgs, 65},
-    {"call_fit_collective_explicit_als", (DL_FUNC) &call_fit_collective_explicit_als, 65},
-    {"call_fit_collective_implicit_als", (DL_FUNC) &call_fit_collective_implicit_als, 53},
+    {"call_fit_collective_explicit_lbfgs", (DL_FUNC) &call_fit_collective_explicit_lbfgs, 64},
+    {"call_fit_collective_explicit_als", (DL_FUNC) &call_fit_collective_explicit_als, 64},
+    {"call_fit_collective_implicit_als", (DL_FUNC) &call_fit_collective_implicit_als, 52},
     {"call_fit_most_popular", (DL_FUNC) &call_fit_most_popular, 20},
-    {"call_fit_content_based_lbfgs", (DL_FUNC) &call_fit_content_based_lbfgs, 42},
-    {"call_fit_offsets_explicit_lbfgs", (DL_FUNC) &call_fit_offsets_explicit_lbfgs, 52},
-    {"call_fit_offsets_explicit_als", (DL_FUNC) &call_fit_offsets_explicit_als, 41},
-    {"call_fit_offsets_implicit_als", (DL_FUNC) &call_fit_offsets_implicit_als, 31},
+    {"call_fit_content_based_lbfgs", (DL_FUNC) &call_fit_content_based_lbfgs, 41},
+    {"call_fit_offsets_explicit_lbfgs", (DL_FUNC) &call_fit_offsets_explicit_lbfgs, 51},
+    {"call_fit_offsets_explicit_als", (DL_FUNC) &call_fit_offsets_explicit_als, 40},
+    {"call_fit_offsets_implicit_als", (DL_FUNC) &call_fit_offsets_implicit_als, 30},
     /* ---------------------------------------------------- */
     {"call_precompute_collective_explicit", (DL_FUNC) &call_precompute_collective_explicit, 31},
     {"call_precompute_collective_implicit", (DL_FUNC) &call_precompute_collective_implicit, 17},
